@@ -13,13 +13,13 @@ def get_root_direct_child_nodes(xml_file, node_tag, node_att_name=None, node_att
     root = xml_file.getroot()
     if root.tag == node_tag:
         return [root]
-    return _get_nodes(root, node_tag, node_att_name, node_att_val)
+    return find_all_nodes(root, node_tag, node_att_name, node_att_val)
 
 
 # will return a list of nodes specified by an attribute key and an attribute value from a parent node
 def get_child_nodes(node_parent, node_tag, node_att_name=None, node_att_val=None):
     selector = node_tag
-    return _get_nodes(node_parent, node_tag, node_att_name, node_att_val)
+    return find_all_nodes(node_parent, node_tag, node_att_name, node_att_val)
 
 
 # will return a list of nodes which doesn't have a specific attribute
@@ -92,6 +92,7 @@ def get_node_att(node, att_name):
 
 # will return an xml file
 def read_xml_file(xml_path):
+    k = et.parse(xml_path)
     return et.parse(xml_path)
 
 
@@ -177,7 +178,7 @@ def simple_dict_to_xml(xml_dict, root_name, output_path):
     # will unpack the parent recursively
     def recursive_unpack_parent(parent_dict, parent=None):
         for key, val in parent_dict.items():
-            parent = add_new_node(xml, key, parent_node=parent)
+            parent = create_and_add_new_node(parent, xml, key)
             if type(val) is dict:
                 recursive_unpack_parent(val, parent)
 
@@ -190,12 +191,12 @@ def get_root_node(xml_file):
     return xml_file.getroot()
 
 
-# bp code for nodes fetching
-def _get_nodes(node, node_tag, node_att_name=None, node_att_val=None):
+# will search for a node recursively
+def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None):
     selector = node_tag
     if node_att_name is not None:
         if node_att_val is not None:
             selector = node_tag + "/[@" + node_att_name + "='" + node_att_val + "']"
         else:
             selector = node_tag + "/[@" + node_att_name + "]"
-    return node.findall(selector)
+    return parent_node.findall(f'.//${selector}')
